;;;;;;;;;;;;;;;;; TEST of orbiteq ;;;;;;;;;;;;;;;;;;;

; 1) Orbits of binary quadrics:

<ring 2 xy r
poly h1 x2     ;A perfect square:
poly h2 xy     ;Two distinct roots

;The ring of coefficients:
<ring 3 a-z s

;The conic as the variety of perfect squares:
<orbiteq
<orbiteq h1 I1
type I1
;should be: b2-4ac

<orbiteq h1 J 4
type J

;The whole of P2
<orbiteq h2 I2
type I2
;there should be no equations

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 2) Orbits of binary cubics:

<ring 2 xy r
poly h1 x3        ;A perfect cube:
poly h2 x2y       ;Two distinct roots
poly h3 xy(x+y)   ;Three distinct roots

;The ring of coefficients:
<ring 4 a-z s

;The twisted cubic as the variety of perfect cubes:
<orbiteq h1 I1 6
res I1 I1
betti I1
degree I1.1

;The tangent developable surface to the twisted cubic (a quartic surface)

<orbiteq h2 I2 12
res I2 I2
betti I2
degree I2.1

;The whole of 3-space:
<orbiteq h3 I3
type I3

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 3) Orbits of binary quartics:

; a) The twisted quartic as the variety of perfect 4th powers:

;A quartic which is a perfect 4th power:
<ring 2 xy r
poly h x4
type h

;The ring of coefficients:
<ring 5 a-z s

setring s
<orbiteq h I
;Took 15 seconds (not any more! -- now about 2.5 secs)

res I I
betti I
; correct answer:
; total:      1     6     8     3
; --------------------------------
;     0:      1     -     -     -
;     1:      -     6     8     3

degree I.1
; correct answer:
; codimension : 3
; degree      : 4

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; b) The orbit of a quartic with 2 distinct roots (the tangent developable):

<ring 2 xy r
poly h x3y

<ring 5 a-z s
<orbiteq h I
res I I
betti I
; correct answer:
; total:      1     3     2
; --------------------------
;     0:      1     -     -
;     1:      -     1     -
;     2:      -     1     1
;     3:      -     1     1

degree I.1
; correct answer:
; codimension : 2
; degree      : 6

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; c) The orbit of a quartic with 3 distinct roots (j = infinity):

<ring 2 xy r
poly h x2y(x+y)
type h

<ring 5 a-z s
<orbiteq h Iinfty
betti Iinfty
; correct answer:
; total:      1     1
; --------------------
;     0:      1     -
;     1:      -     -
;     2:      -     -
;     3:      -     -
;     4:      -     -
;     5:      -     1

type Iinfty
; correct answer:
; b2c2d2-4ac3d2-4b3d3+18abcd3-27a2d4-4b2c3e+16ac4e+18b3cde-80abc2de-6ab2d2e \
;     +144a2cd2e-27b4e2+144ab2ce2-128a2c2e2-192a2bde2+9/125a3e3

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; d) The orbit of a quartic with 4 distinct roots, lambda = -1, j=1728:

<ring 2 xy r
poly h xy(x-y)(x+y)
type h

<ring 5 a-z s

<orbiteq h I1728
betti I1728
; correct answer:
; total:      1     1
; --------------------
;     0:      1     -
;     1:      -     -
;     2:      -     1

type I1728
;should be: c3-9/2bcd+27/2ad2+27/2b2e-36ace

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; e) The orbit of a quartic with 4 distinct roots, j = 0:

<ring 2 xy r
poly h (x3-y3)y
type h

<ring 5 a-z s

<orbiteq h I0
;this computation goes to degree 23, though only degree 8 is
;actually necessary.  Because of bad order??
betti I0
; correct answer:
; total:      1     1
; --------------------
;     0:      1     -
;     1:      -     1

type I0
;should be: c2-3bd+12ae

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 4) Ternary cubics (elliptic curves)

<ring 3 xyz r
poly h0 x3+y3+z3      ; j = 0

<ring 10 a-z s

<orbiteq h0 J0 12
betti J0
; correct answer:
; total:      1     1
; --------------------
;     0:      1     -
;     1:      -     -
;     2:      -     -
;     3:      -     1

type J0
; correct answer:
; f4-8ef2g+16e2g2+24defh-8cf2h-16cegh+24bfgh-48ag2h+16c2h2-48bdh2-48de2i \
;     +24cefi-8bf2i-16begi+24afgi-16bchi+144adhi+16b2i2-48aci2-48c2ej+144bdej \
;     +24bcfj-216adfj-48b2gj+144acgj

listvars
;;;;;;;;;;;;;;;;;;;;; END test of orbiteq ;;;;;;;;;;;;;;;;;;;;;;;
reset
$



