;;;;;;;;;;;;;;;;; TEST of pushfwd ;;;;;;;;;;;;;;;;;;;

;Illustration of the Auslander-Buchsbaum formula:
;pd M = depth R - depth M.
;If we push M forward by a map f such that M is finitely generated via f,
;then the depth of M does not change, so the projective dimension goes down:
;Also, if the projection is linear, the degree stays the same.  Of course
;the number of generators generally goes up.

<ring 6 a-z r6

;A module of projective dimension 2:
<genermat a 2 3 m
res m mm

<ring 5 a-z r5
<ring 4 a-z r4

;Amap from r5 to r6
imap g r5 r6
a a+b+c+d+e+f
;
type g

;A generic projection map from r4 to r5
setring r5
<randomat 1 4 r5 f
type f

setring r5
<pushfwd
<pushfwd g m p
<prune p p
res p pp

setring r4
<pushfwd f p q
res q qq

type m
betti mm
degree mm.1
type p
betti pp
degree pp.1
type q
betti qq
degree qq.1

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;Generic projection of the homogeneous coordinate ring of the
;twisted cubic into the plane.  The result is the normalization
;of the ideal of the nodal cubic:

;Projective 3-space and 2-space:
<ring 4 a-z P3
<ring 3 a-z P2

;The ideal of the twisted cubic:
setring P3
cat a m
0 1
0 1 2
wedge m 2 i

;A generic projection
<randomat 1 3 P3 f

setring P2
<pushfwd f i j

;The result is not the ring of a subscheme of the plane:
betti j
;But it is an algebra of genus 0, degree 3 (it's the same homogeneous
;coordinate ring of the twisted cubic):
std j j
hilb j
; correct answer:
; codimension = 1
; degree      = 3
; genus       = 0

;The support is a cubic (genus 1) in the plane -- nodal, of course:
<ann j k
betti k
std k k
hilb k
; correct answer:
; codimension = 1
; degree      = 3
; genus       = 1

listvars
;;;;;;;;;;;;;;;;;;; END test of pushfwd ;;;;;;;;;;;;;;;;;;
reset
$


