;;;;;;;;;;;;;;;;;;;;; TEST of pushfwd1 ;;;;;;;;;;;;;;;;;

; 1) Sheaves on P1 x P1

ring r
;
4
x[1]-x[2]
y[1]-y[2]
;
;

cat x[1] xvars
0
0..1
cat y[1] yvars
0
0..1

transpose yvars yvars'
mult yvars' xvars zvars
flatten zvars f
type f

;The bihomogeneous ideal of a point:
ideal i
2
x[1]
y[1]

;A bihomogeneous ideal of the empty set:
ideal j
2
x[1]
x[2]

;The twisted cubic:
ideal k
1
x[1]y[1]2+x[2]y[2]2

;Since 1 in r is of degree 0,0, we can take M0 = r/i
;and no modulo is necessary.

<ring 4 z[1,1]-z[2,2] s

<pushfwd1
<pushfwd1 f i N
nres N N
betti N ;the ideal of a point
; correct answer:
; total:      1     3     3     1
; --------------------------------
;     0:      1     3     3     1

<pushfwd1 f j N
nres N N
betti N ;the ideal of the empty set
; correct answer:
; total:      1     4     6     4     1
; --------------------------------------
;     0:      1     4     6     4     1

<pushfwd1 f k N 4
nres N N ;the ideal of the twisted cubic
betti N
; correct answer:
; total:      1     3     2
; --------------------------
;     0:      1     -     -
;     1:      -     3     2
degree N.1
; should be:
; codimension : 2
; degree      : 3

; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 2) Yau's example projected to P2xP3

;The bihomogeneous coordinate ring of P3 x P3:
ring r
;
8
a[0]-a[3]
b[0]-b[3]
;
;

;The ideal of the product of two cubic surfaces, cut by a hyperplane:
ideal i
3
a[0]3+a[1]3+a[2]3+a[3]3
b[0]3+b[1]3+b[2]3+b[3]3
a[0]b[0]+a[1]b[1]+a[2]b[2]+a[3]b[3]

std i ii
degree ii
; correct answer:
; codimension : 3
; degree      : 18

ring s
;
7
a[0]-a[2]
b[0]-b[3]
1
;
pring s

;Now choose 2 linear forms in the a's.
;We want the projection
;to be birational.  Think of it as P3xP3 -> P2xP3.  Note that we need to
;project from a point p in P3 such that p x P3 doesn't meet Yau's variety X.
;Luckily the projection of X to P3 is contained in the cubic hypersurface.
;Thus simply taking the first 3 vars should be ok:

imap f s r
;
setring s
<pushfwd1 f i n

std n n
degree n
; correct answer:
; codimension : 2
; degree      : 18
numinfo n
type n.1

;The projection to P3 is still the cubic, so any pair of b variables will
;give a well defined map to P2xP2.  However,
;we get something which is not birational

ring s1
;
6
a[0]-a[2]
b[0]-b[2]
1
;
pring s1

;Now choose 3 linear forms in the b's

imap f1 s1 s
b[0] b[0]+5b[3]
;
setring s1
set prlevel -1 ; the following uses 3200 KB and goes to deg 39
<pushfwd1 f1 n n1

std n1 n1
degree n1
;The result is not birational -- it has the wrong degree.

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 3) Test the safety net:

<ring 3 a-c r
<zeromat 1 0 f   ;no cols
type f
ncols f nc
type nc
nrows f nr
type nr
<pushfwd1 f r test

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 4) An example of pushing forward from a factor ring:

;The middle monomial ribbon of genus 5:
;Define s=k[s,t,y]/y2

<ring 3 sty s
<ideal i y2
std i i
qring i s
<zeromat 1 0 pres_of_s ;A presentation of the free module of rank 1.

;Define the ideal tot of generators of the subring
;defining the middle monomial ribbon:
<ideal tot t4 t3s t2s2 ts3-t3y s4-2st2y
type tot

<ring 5 a-z s
<pushfwd1 tot pres_of_s rib 8  ;7 is not enough!
type rib
res rib rib
betti rib

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 5) Some linear projections:

<ring 3 a-z P2
<ring 4 a-z P3
<ideal curve a5+b5+c5+d5 ab+ac+bc
<ideal f a+d b+2d c

setring P2
<pushfwd1 f curve planecurve 10 ;the 10 helps a little here
;takes 4.25 secs (6.28 without the linear code)
type planecurve

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 6) A hard example:

<ring 5 a-z r
ideal i
3
a5+b5+c5+d5+e5-5abcde
ea3b+ab3c+bc3d+cd3e+de3a
e2ab2+a2bc2+b2cd2+c2de2+d2ea2
std i i
degree i
; correct answer:
; codimension : 2
; degree      : 15

;eliminate one variable to make it principal
<ideal f a+b 2a+c 3a+d 4a+e

<ring 4 a-z r1
set prlevel -1   ;do this only if you have time and space!
;<pushfwd1 f i j
;Without the linear code:
;time 160 minutes , 17**K of space, to degree 16
;The resulting 15th degree form took 2 seconds to print!
;With the linear code: 78 minutes, about the same space.
type j

;The simplest possible projection of the same ideal:
<ring 5 a-z r

ideal i
3
a5+b5+c5+d5+e5-5abcde
ea3b+ab3c+bc3d+cd3e+de3a
e2ab2+a2bc2+b2cd2+c2de2+d2ea2

<ideal f b c d e

<ring 4 a-z r1
set prlevel -1
<pushfwd1 f i j 15
;half as long with the 15 as without.
;half as long with with the linear code as without.
betti j

type j
std j j

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 7) A test of the linear case (was a bug till 5/18/90)

<ring 2 a-z T
<ideal vertex b
<ideal map b

<ring 1 x[1] T1
<pushfwd1 map vertex A1
type A1
;should be: x[1]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 8) Another sort of linear example:

;Was a bug in the linear code till 11/10/90
;First test the routine that really makes a projection,
;the "main case" of linear projection

<ring 2 uv S1
<ideal J u4 v4
forcestd J J
qring J S
<zeromat 1 0 pres_of_S

<ideal map u+v
<ring 1 t R

set prlevel -1
<pushfwd1 map pres_of_S X 7

type X
; should be: t7

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; 9) Next test the "easy case" of linear projection

<ring 2 uv S1
<ideal J u4 v3
forcestd J J
qring J S
<zeromat 1 0 pres_of_S

<ideal map v u
<ring 2 st R

set prlevel -1
<pushfwd1 map pres_of_S X 1
;the maxdegree option has no effect in this case.

type X
; should be: t4 s3

listvars
;;;;;;;;;;;;;;;;;;;;;;;; END test of pushfwd1 ;;;;;;;;;;;;;;
reset
$


